summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGeert Bosch <geert@mongodb.com>2017-03-14 17:39:17 +1100
committerGeert Bosch <geert@mongodb.com>2017-03-29 11:55:01 -0400
commit83007991e9eaba391988c4161fe8f68352c57939 (patch)
tree4c3141f7f4a42a7fcc4e7669457d76765f5be8e4
parentc31befb4c2870bc0e615ab09645ace281906cea5 (diff)
downloadmongo-83007991e9eaba391988c4161fe8f68352c57939.tar.gz
SERVER-28533 Have collation.js ignore UUIDs in CollectionInfo comparison
-rw-r--r--jstests/core/collation.js4
1 files changed, 3 insertions, 1 deletions
diff --git a/jstests/core/collation.js b/jstests/core/collation.js
index f73ea604650..ac89db598b6 100644
--- a/jstests/core/collation.js
+++ b/jstests/core/collation.js
@@ -1978,9 +1978,11 @@
var destCollectionInfos = destDB.getCollectionInfos({name: coll.getName()});
// The namespace for the _id index will differ since the source and destination collections
// are in different databases.
delete sourceCollectionInfos[0].idIndex.ns;
+ delete sourceCollectionInfos[0].info.uuid;
delete destCollectionInfos[0].idIndex.ns;
+ delete destCollectionInfos[0].info.uuid;
assert.eq(sourceCollectionInfos, destCollectionInfos);
assert.eq([{_id: "FOO"}], destDB[coll.getName()].find({_id: "foo"}).toArray());
@@ -1978,9 +1978,11 @@
var destCollectionInfos = destDB.getCollectionInfos({name: coll.getName()});
// The namespace for the _id index will differ since the source and destination collections
- // are in different databases.
+ // are in different databases. Same for UUID.
delete sourceCollectionInfos[0].idIndex.ns;